pub struct ResortOperatingDay {
pub location_id: LocationId,
pub date: NaiveDate,
pub snapshot_id: Id,
}Expand description
Source snapshot key for one resort’s manager brief on an operating day.
Fields
location_id: LocationIdLocation id fact promoted into this daily brief contract.
date: NaiveDateDate fact promoted into this daily brief contract.
snapshot_id: IdSnapshot id fact promoted into this daily brief contract.