pub enum RevenueOpportunityKind {
ExitBathAfterBoarding,
GroomingRebookingDue,
DaycarePackageCandidate,
TrainingConsultCandidate,
HolidayBoardingWaitlistFill,
}Expand description
Domain vocabulary for revenue opportunity kind decisions in daily brief workflows.
Variants
ExitBathAfterBoarding
Exit bath after boarding item surfaced for manager daily-brief triage.
GroomingRebookingDue
Grooming rebooking due item surfaced for manager daily-brief triage.
DaycarePackageCandidate
Daycare package candidate item surfaced for manager daily-brief triage.
TrainingConsultCandidate
Training consult candidate item surfaced for manager daily-brief triage.
HolidayBoardingWaitlistFill
Holiday boarding waitlist fill item surfaced for manager daily-brief triage.